@@ -15,6 +15,15 @@ is_tab = '\t'.__eq__
 
 cur_path = os.path.dirname(__file__)
 
+import os
+import sys
+
+#notfaj was here
+def resource_path(relative_path):
+    if hasattr(sys, '_MEIPASS'):
+        return os.path.join(sys._MEIPASS, relative_path)
+    return os.path.join(os.path.abspath("."), relative_path)
+
 @logger.catch()
 async def go_through_dialog(p):
     while await p.is_in_dialog():
@@ -675,7 +684,7 @@ async def goToNewWorld(p, destinationWorld):
     return bigStackDestinations
 
 async def parseFile(fileName, worldName):
-    file = open(f"{cur_path}/{fileName}", "r")
+    file = open(resource_path(f"{cur_path}/{fileName}"), "r")
 
     lines = file.readlines()
     start = 'WORLD - ' + worldName + '\n'
@@ -972,7 +981,7 @@ async def toZoneDisplayName(clients, destinationZoneDisplay):
                  "Wysteria", "Zafaria", "Avalon", "Azteca", "Khrysalis", "Polaris", "Arcanum", "Mirage", "Empyrea",
                  "Karamelle", "Lemuria"]
 
-    file = open(f"{cur_path}/{'traversalData/displayZones.txt'}", "r")
+    file = open(resource_path(f"{cur_path}/{'traversalData/displayZones.txt'}"), "r")
     lines = file.readlines()
     lines = iter(lines)
     destinationZone = ''
